<?php
/**
 * Nexter Builder Sections Conditional
 *
 * @package Nexter Extensions
 * @since 1.0.0
 */

if ( ! class_exists( 'Nexter_Builder_Sections_Conditional' ) ) {

	class Nexter_Builder_Sections_Conditional {

		/**
		 * Member Variable
		 */
		private static $instance;
		
		/**
		 * Conditional Sections
		 */
		 public static $sections_ids =array();
		 
		 
		/**
		 *  Initiator
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self;
			}
			return self::$instance;
		}

		/**
		 *  Constructor
		 */
		public function __construct() {
			add_action( 'wp', array( $this, 'get_sections_ids' ), 1 );
			add_action( 'template_redirect', array( $this, 'nexter_builder_template_frontend' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'load_sections_enqueue_styles' ) );
		}
		
		public function get_sections_ids(){
			
			$options = [
				'location'  => 'nxt-add-display-rule',
				'exclusion' => 'nxt-exclude-display-rule',
			];

			self::$sections_ids = Nexter_Builder_Display_Conditional_Rules::get_instance()->get_templates_by_sections_conditions( NXT_BUILD_POST, $options );
			
		}
		
		/**
		 * Load Hooks Enqueue Styles
		 */
		public function load_sections_enqueue_styles() {
			if(!empty(self::$sections_ids)){
				foreach ( self::$sections_ids as $post_id => $post_data ) {

					if ( class_exists( 'Nexter_Builder_Compatibility' ) ) {
						$page_base_instance = Nexter_Builder_Compatibility::get_instance();

						$page_builder_instance = $page_base_instance->get_active_page_builder( $post_id );

						if ( is_callable( array( $page_builder_instance, 'enqueue_scripts' ) ) ) {
							$page_builder_instance->enqueue_scripts( $post_id );
						}
					}
				}
			}
		}

		/**
		 * Don't display the templates on the frontend for non edit_posts
		 */
		public function nexter_builder_template_frontend() {
			if ( is_singular( NXT_BUILD_POST ) && ! current_user_can( 'edit_posts' ) ) {
				wp_redirect( home_url(), 301 );
				die;
			}
		}
		
		/*
		 * Load Sections Condition Hooks
		 * @since 1.0.4
		 */
		public static function nexter_sections_condition_hooks($nxt_layout='', $sections_pages='' ) {
			$get_result=array();
			if( !empty(self::$sections_ids) ) {
			
				foreach ( self::$sections_ids as $post_id => $post_data ) {
					$post_type = get_post_type();

					if ( NXT_BUILD_POST != $post_type ) {
						$nxt_hooks_layout   = get_post_meta( $post_id, 'nxt-hooks-layout', true );
						$sections   = get_post_meta( $post_id, 'nxt-hooks-layout-sections', false );
						$codes_snippet   = get_post_meta( $post_id, 'nxt-hooks-layout-code-snippet', false );
						$pages   = get_post_meta( $post_id, 'nxt-hooks-layout-pages', false );

						if( ( !empty( $nxt_layout ) && $nxt_hooks_layout == $nxt_layout ) && ( !empty( $sections_pages ) && !empty($sections) &&$sections[0] == $sections_pages ) ){
							$get_result[] = $post_id;
							
						}else if( ( !empty($nxt_hooks_layout) && !empty( $nxt_layout ) && $nxt_hooks_layout == $nxt_layout ) && (!empty($pages) && !empty( $sections_pages ) && $pages[0] == $sections_pages ) ){
							$get_result[] = $post_id;
							
						}else if( ( !empty($nxt_hooks_layout) && !empty( $nxt_layout ) && $nxt_hooks_layout == $nxt_layout ) && (!empty($codes_snippet) && !empty( $sections_pages ) && $codes_snippet[0] == $sections_pages ) ){
						
							$get_result[] = $post_id;
							
						}
					}
				}
			}
			return $get_result;
		}
		
		/**
		 * Nexter Builder Conditional get template content
		 */
		public function get_action_content( $post_id ) {

			$action = get_post_meta( $post_id, 'nxt-display-hooks-action', true );
			
			// Exclude div wrapper if selected hook is from below list.
			$exclude_hooks = array( 'nxt_html_before', 'nxt_body_top', 'nxt_head_top', 'wp_head', 'nxt_head_bottom',  'nxt_body_bottom', 'wp_footer' );
			$nxt_hook_wrapper	= ! in_array( $action, $exclude_hooks );
			if ( $nxt_hook_wrapper ) {
				echo '<div class="nxt-template-load nxt-load-hook-' . esc_attr($post_id) . '" data-id="' . esc_attr($post_id) . '">';
			}
			
			if ( function_exists('nexter_content_load') ) {
				nexter_content_load( $post_id );
			}
			
			if ( $nxt_hook_wrapper ) {
				echo '</div>';
			}
		}

	}
}

Nexter_Builder_Sections_Conditional::get_instance();